/* 
 * Distributed as part of jtmail 1.0
 * 
 * Copyright (C) 2008 QArks.com
 *
 * Author: Pierre Meyer <support@qarks.com>
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2.1, as 
 * published by the Free Software Foundation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; see the file LICENSE.  If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */
package com.qarks.util.mail;

import java.util.Date;

public class Attachment {

	private String displayName="";
	private String fullPath="";
	private int id = -1;
	private int mailUid;
	public static final int NORMAL = 1;
	public static final int DETACHED = 2;
	public static final int DELETED = 3;
	private int state = NORMAL;
	private boolean inline;
	private MailTarget from;
	private Date date;
	private static final String FILE_TYPE = "file://";
	private MailAttachmentUID uid;

	public Attachment(){
		uid = MailAttachmentUID.getNewObjectUID();
	}

	public Attachment(String displayName,String fullPath) {
		this();
		this.displayName = displayName;
		if (fullPath.toLowerCase().startsWith(FILE_TYPE)){
			this.fullPath = fullPath.substring(FILE_TYPE.length()+1);
		}
		else{
			this.fullPath = fullPath;
		}
	}

	public Object clone(){
		Attachment clone = new Attachment(displayName, fullPath);
		clone.from = from;
		clone.date = date;
		clone.inline = inline;
		clone.state = state;
		clone.id = id;
		clone.mailUid = mailUid;
		return clone;
	}

	public String getContentId(){
		String ext = "";
		int index = displayName.lastIndexOf(".");
		if (index>-1){
			ext = displayName.substring(index);
		}
		String result = "id"+"."+uid+ext;
		return result;
	}

	public static void main(String args[]){
		Attachment at = new Attachment("test.jpg","test");
		System.out.println(at.getContentId());
	}

	public boolean equals(Object obj){
		boolean result = false;
		if (obj instanceof Attachment){
			Attachment at = (Attachment)obj;
			result = (id==at.getId());			
		}
		return result;
	}

	public void setDetached(boolean detached){
		state = detached? DETACHED:NORMAL;
	}

	public int getId(){
		return id;
	}

	public int getMailUid(){
		return mailUid;
	}

	public void setId(int id){
		this.id = id;
	}

	public void setMailUid(int uid){
		this.mailUid = uid;
	}

	public String getDisplayName(){
		return this.displayName;
	}

	public void setDisplayName(String name){
		this.displayName = name;
	}

	public String getFullPath(){
		return this.fullPath;
	}

	public void setFullPath(String fullPath){
		if (fullPath.toLowerCase().startsWith(FILE_TYPE)){
			this.fullPath = fullPath.substring(FILE_TYPE.length()+1);
		}
		else{
			this.fullPath = fullPath;
		}
	}

	public String toString(){
		return "ATTACHMENT "+this.displayName;
	}
	public int getState() {
		return state;
	}
	public void setState(int state) {
		this.state = state;
	}
	public boolean isInline() {
		return inline;
	}
	public void setInline(boolean inline) {
		this.inline = inline;
	}
	public MailTarget getFrom() {
		return from;
	}
	public void setFrom(MailTarget from) {
		this.from = from;
	}
	public Date getDate() {
		return date;
	}
	public void setDate(Date date) {
		this.date = date;
	}
}