/* 
 * Distributed as part of jtmail 1.0
 * 
 * Copyright (C) 2008 QArks.com
 *
 * Author: Pierre Meyer <support@qarks.com>
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2.1, as 
 * published by the Free Software Foundation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; see the file LICENSE.  If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */
package com.qarks.util.mail;

import java.util.*;
import java.io.Serializable;

public final class MailAttachmentUID implements Serializable {

	private long time = -1;
	private double random = -1;

	public MailAttachmentUID() {
	}

	public static MailAttachmentUID getNewObjectUID(){
		MailAttachmentUID uid = new MailAttachmentUID();
		uid.time = new Date().getTime();
		uid.random = Math.random();
		return uid;
	}

	public static void main(String args[]){
		MailAttachmentUID uid = new MailAttachmentUID();
		System.out.println("uid: "+uid.toString());
	}

	public Object clone(){
		MailAttachmentUID result = new MailAttachmentUID();
		result.time = time;
		result.random = random;
		return result;
	}

	public boolean equals(Object object) {
		boolean equals = false;
		if (object != null) {
			if (object.getClass().equals(MailAttachmentUID.class)) {
				MailAttachmentUID ObjectUID = (MailAttachmentUID) object;
				equals = (ObjectUID.time == time) && (ObjectUID.random == random);
			}
		}
		return equals;
	}

	public int hashCode() {
		final long longRandom = Double.doubleToLongBits(random);
		return (int) (longRandom ^ (longRandom >> 32));
	}

	public String toString() {
		StringBuffer s = new StringBuffer();
		s.append(Long.toHexString(time));
		s.append("_");
		s.append(Long.toHexString(Double.doubleToLongBits(random)));
		return s.toString();
	}

	public static MailAttachmentUID fromStringToObjectUID(String string) {
		MailAttachmentUID objectUID = new MailAttachmentUID();
		StringTokenizer s = new StringTokenizer(string, "_", false);
		objectUID.time = Long.parseLong(s.nextToken(), 16);
		objectUID.random = Double.longBitsToDouble(Long.parseLong(s.nextToken(), 16));
		return objectUID;
	}

	public static MailAttachmentUID fromLongStringToObjectUID(String string) {
		MailAttachmentUID objectUID = new MailAttachmentUID();
		StringTokenizer s = new StringTokenizer(string, "_", false);
		objectUID.time = Long.parseLong(s.nextToken(), 10);
		objectUID.random = Long.parseLong(s.nextToken(), 10);
		return objectUID;
	}

	public double getRandom() {
		return random;
	}
	public long getTime() {
		return time;
	}
	public void setRandom(double random) {
		this.random = random;
	}
	public void setTime(long time) {
		this.time = time;
	}
}
