/* 
 * Distributed as part of jtmail 1.0
 * 
 * Copyright (C) 2008 QArks.com
 *
 * Author: Pierre Meyer <support@qarks.com>
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2.1, as 
 * published by the Free Software Foundation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; see the file LICENSE.  If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */
package com.qarks.util.mail;

import java.io.File;
import java.util.ArrayList;

public class MailBuilder {

	private static final String CID = "cid:";
	private static final String SRC = "src";
	private static final String BACKGROUND = "background";
	private static final String IMG = "img ";
	private static final String BODY = "body ";

	public static void extractInlinePictures(MessageContent message, String templatePath, ProgressListener listener){
		Attachment orig[] = message.getAttachments();
		ArrayList<Attachment> list = new ArrayList<Attachment>();
		for (int i = 0; i < orig.length; i++) {
			list.add(orig[i]);
		}
		StringBuffer content=new StringBuffer();
		ArrayList<String> tokens = extractTokens(message.getContent());
		for(int i=0;i<tokens.size();i++){
			String token = tokens.get(i);
			if (isMetaSection(token)){
				String sectionLowerCase = token.toLowerCase();
				int srcIndex = -1;
				String start;
				int urlStartIndex,urlEndIndex;
				boolean imageImg = false;
				boolean imageBody = false;
				int tagLength;
				imageImg = ((sectionLowerCase.indexOf(IMG)>-1)&& ((srcIndex=sectionLowerCase.indexOf(SRC))>-1));
				tagLength = SRC.length();

				if (!imageImg){
					imageBody = ((sectionLowerCase.indexOf(BODY)>-1) &&((srcIndex=sectionLowerCase.indexOf(BACKGROUND))>-1));
					tagLength = BACKGROUND.length();
				}

				if (imageImg || imageBody){
					start = token.substring(0,srcIndex+tagLength);
					String url = token.substring(srcIndex+tagLength);
					urlStartIndex = url.indexOf("\"");
					if (urlStartIndex>-1 && start.length()>(urlStartIndex+1)){
						String temp = url.substring(urlStartIndex+1);
						urlEndIndex = temp.indexOf("\"");
						if (urlEndIndex>-1){
							String path = temp.substring(0,urlEndIndex);
							while((path.startsWith("/")||path.startsWith("\\"))&&(path.length()>1)){
								path = path.substring(1);
							}
							File file = new File(path);
							if (!file.exists()){
								// maybe the path was relative..
								file = new File(templatePath+File.separator+path);
							}
							if (file.exists()) {
								if (listener!=null){
									listener.onInlinePictureAppended(file.getAbsolutePath(),file.length());
								}
								Attachment at = new Attachment(file.getName(), file.getAbsolutePath());
								at.setDisplayName(at.getContentId());
								at.setInline(true);
								list.add(at);
								String newUrl = "\"" + path + "\"";

								newUrl = "\"" + CID + at.getContentId() + "\"";
								// update the token
								token = start + url.substring(0,urlStartIndex) + newUrl + temp.substring(urlEndIndex);
							}
							else{
								System.err.println("inline picture not found: "+path);
							}
						}
					}
				}
				content.append(token);
			}
			else{
				content.append(token);
			}
		}

		Attachment ats[] = (Attachment[])list.toArray(new Attachment[0]);
		message.setAttachments(ats);
		String contentString = content.toString();
		message.setContent(contentString);

	}

	public static ArrayList<String> extractTokens(String html){
		ArrayList<String> result = new ArrayList<String>();
		String toParse = html;
		String left = html;
		String section;
		int openIndex,closeIndex;
		boolean forceEnd = false;
		while(!forceEnd && (openIndex = toParse.indexOf("<"))>-1){
			if (openIndex>0){
				result.add(toParse.substring(0, openIndex));
				section = toParse.substring(openIndex);
			}
			else{
				section = toParse;
			}
			if (section.length()>0){
				closeIndex = section.indexOf(">");
				if (closeIndex>-1){
					section = section.substring(0,closeIndex+1);
					left = toParse.substring(section.length()+openIndex);
					toParse = left;
					result.add(section);
				}
				else{
					// a section is left unclosed, this is not normal but ok...
					forceEnd = true;
				}
			}
			else{
				// the '<' was the last char, this is not normal but ok..
				// next time, we go out of the loop
			}
		}
		result.add(left);
		return result;
	}

	public static boolean isMetaSection(String section){
		String test = section.trim().toLowerCase();
		return (test.startsWith("<") && test.endsWith(">"));
	}

}
