/* 
 * Distributed as part of jtmail 1.0
 * 
 * Copyright (C) 2008 QArks.com
 *
 * Author: Pierre Meyer <support@qarks.com>
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2.1, as 
 * published by the Free Software Foundation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; see the file LICENSE.  If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */
package com.qarks.util.mail;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.Vector;

public class MailFileHelper {

	public static byte[] getDigest(byte[] buffer) throws IOException {
		byte[] result = new byte[0];
		try {
			MessageDigest md5 = MessageDigest.getInstance("MD5");
			result = md5.digest(buffer);
		}
		catch (NoSuchAlgorithmException e) {
			throw new IOException(e.getMessage());
		}
		return result;
	}

	public static String getFileContent(File file, String charsetName) throws IOException {
		StringBuffer buf = new StringBuffer();
		FileInputStream fis = null;
		try {
			fis = new FileInputStream(file);
			BufferedInputStream bis = new BufferedInputStream(fis);
			InputStreamReader freader = new InputStreamReader(bis, charsetName);
			char array[] = new char[2000];
			int read = 0;
			while ( (read = freader.read(array)) > -1) {
				if (read > 0) {
					buf.append(array, 0, read);
				}
				else {
					try {
						Thread.sleep(50);
					}
					catch (Exception ex) {}
				}
			}
			freader.close();
		}
		finally {
			if (fis != null) {
				fis.close();
			}
		}
		return buf.toString();
	}

	public static String getFileContent(File file) throws IOException {
		FileReader freader = null;
		StringBuffer buf = new StringBuffer();
		try {
			freader = new FileReader(file);
			char array[] = new char[2000];
			int read = 0;
			while ( (read = freader.read(array)) > -1) {
				if (read > 0) {
					buf.append(array, 0, read);
				}
				else {
					try {
						Thread.sleep(50);
					}
					catch (Exception ex) {}
				}
			}
		}
		finally {
			if (freader!=null){
				freader.close();
			}
		}
		return buf.toString();
	}

	public static String getFileContent(InputStream is) {
		StringBuffer buf = new StringBuffer();
		try {
			InputStreamReader freader = new InputStreamReader(is);
			char array[] = new char[2000];
			int read = 0;
			while ( (read = freader.read(array)) > -1) {
				if (read > 0) {
					buf.append(array, 0, read);
				}
				else {
					Thread.sleep(50);
				}
			}
			freader.close();
		}
		catch (Exception ex) {
			ex.printStackTrace();
		}
		return buf.toString();
	}

	public static void writeContentToFile(String content, File file) throws IOException {
		OutputStream fos = null;
		try {
			fos = new BufferedOutputStream(new FileOutputStream(file));
			byte array[] = content.getBytes();
			fos.write(array);
		}
		finally {
			if (fos != null) {
				fos.close();
			}
		}
	}

	public static void writeContentToFile(InputStream is, File file) throws IOException {
		OutputStream fos = null;
		try {
			fos = new BufferedOutputStream(new FileOutputStream(file));
			byte array[] = new byte[2048];
			int nbread = 0;
			while((nbread=is.read(array))>-1){
				fos.write(array,0,nbread);
			}
		}
		finally {
			if (fos != null) {
				fos.close();
			}
		}
	}

	public static byte[] getFileBytes(File file) throws IOException {
		ByteArrayOutputStream baos = new ByteArrayOutputStream();
		InputStream fis = null;
		try {
			fis = new BufferedInputStream(new FileInputStream(file));
			byte array[] = new byte[2000];
			int read = 0;
			while ( (read = fis.read(array)) > -1) {
				baos.write(array, 0, read);
			}
			baos.close();
		}
		catch (Exception ex) {
			ex.printStackTrace();
		}
		finally {
			if (fis != null) {
				fis.close();
			}
		}
		return baos.toByteArray();
	}

	public static void writeBytesToFile(byte[] data, File file) throws IOException {
		OutputStream fos = null;
		try {
//			fos = new ThreadedOutputStream(new FileOutputStream(file),50*1024);
			fos = new BufferedOutputStream(new FileOutputStream(file));
			fos.write(data);
		}
		finally {
			if (fos != null) {
				fos.close();
			}
		}
	}

	public static boolean deleteDir(File dir) {
		cleanDir(dir);
		return dir.delete();
	}

	/**
	 * delete files and directories in the directory #dir#
	 * @param dir File
	 * @return boolean true if succeded
	 */
	public static boolean cleanDir(File dir) {
		// to see if this directory is actually a symbolic link to a directory,
		// we want to get its canonical path - that is, we follow the link to
		// the file it's actually linked to
		File candir;
		try {
			candir = dir.getCanonicalFile();
		}
		catch (IOException e) {
			return false;
		}

		// a symbolic link has a different canonical path than its actual path,
		// unless it's a link to itself
		if (!candir.equals(dir.getAbsoluteFile())) {
			// this file is a symbolic link, and there's no reason for us to
			// follow it, because then we might be deleting something outside of
			// the directory we were told to delete
			return false;
		}

		// now we go through all of the files and subdirectories in the
		// directory and delete them one by one
		File[] files = candir.listFiles();
		if (files != null) {
			for (int i = 0; i < files.length; i++) {
				File file = files[i];

				// in case this directory is actually a symbolic link, or it's
				// empty, we want to try to delete the link before we try
				// anything
				boolean deleted = file.delete();
				if (!deleted) {
					// deleting the file failed, so maybe it's a non-empty
					// directory
					if (file.isDirectory()) {
						deleteDir(file);
					}
					// otherwise, there's nothing else we can do
				}
			}
		}
		return true;
	}

	public static long getDirectorySize(File file) {
		long result = 0;
		if (file.isDirectory()) {
			File listFiles[] = file.listFiles();
			for (int i = 0; i < listFiles.length; i++) {
				result += getDirectorySize(listFiles[i]);
			}
		}
		else {
			result = file.length();
		}
		return result;
	}

	public static int replaceString(File file, String stringToReplace, String newString) throws IOException {
		int nbReplacedString = 0;

		BufferedReader bufferedReader = new BufferedReader(new FileReader(file));
		Vector readLines = new Vector();
		while (true) {
			String readLine = bufferedReader.readLine();
			if (readLine == null) {
				bufferedReader.close();
				break;
			}

			// perform the replacement
			StringBuffer str = new StringBuffer(256);
			for (int i = 0; i < readLine.length(); i++) {
				if (readLine.regionMatches(i, stringToReplace, 0, stringToReplace.length())) {
					str.append(newString);
					i += stringToReplace.length() - 1;
					nbReplacedString++;
				}
				else {
					str.append(readLine.charAt(i));
				}
			}

			readLines.addElement(str.toString());
		}

		BufferedWriter bufferedWriter = new BufferedWriter(new FileWriter(file));
		for (int numLine = 0; numLine < readLines.size(); numLine++) {
			bufferedWriter.write( (String) (readLines.elementAt(numLine)));
			bufferedWriter.newLine();
		}
		bufferedWriter.close();

		return nbReplacedString;
	}

	public static void deleteHierarchy(File file) throws IOException {
		if (file.isDirectory()) {
			File listFiles[] = file.listFiles();
			for (int i = 0; i < listFiles.length; i++) {
				deleteHierarchy(listFiles[i]);
			}
			if (file.exists() && !file.delete()){
				throw new IOException("folder "+file.getAbsolutePath()+" cannot be deleted");
			}
		}
		if (file.exists() && !file.delete()){
			throw new IOException("file "+file.getAbsolutePath()+" cannot be deleted");
		}
	}

	public static String replaceIllegals(String fileName, char replaceChar) {
		String result = fileName;
		char illegalChars[] = new char[] {'/', '\\', ':', '*', '?', '<', '>', '|'};
		for (int i = 0; i < illegalChars.length; i++) {
			result = result.replace(illegalChars[i], '_');
		}
		return result;
	}

}
