/* 
 * Distributed as part of jtmail 1.0
 * 
 * Copyright (C) 2008 QArks.com
 *
 * Author: Pierre Meyer <support@qarks.com>
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2.1, as 
 * published by the Free Software Foundation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; see the file LICENSE.  If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */
package com.qarks.util.mail;

import java.util.*;

public class MessageContent {

	public final long serialVersionUID = 19232391;

	protected String subject;
	protected String content;
	protected Attachment []attachments;
	protected MailTarget from;
	private MailTarget [] tos;
	private MailTarget [] ccs;
	private MailTarget [] bccs;
	private MailTarget replyTo;
	protected Date sendDate;
	protected boolean hasBeenRead;
	private String contentAsText;
	private boolean sendAsText;

	public MessageContent(){
		replyTo = new MailTarget();
		from = new MailTarget();
		tos = new MailTarget[0];
		ccs = new MailTarget[0];
		bccs = new MailTarget[0];
		content = "";
		subject = "";
		attachments = new Attachment[0];
		sendDate = new Date();
		hasBeenRead = false;
	}

	public MessageContent(MailTarget from,MailTarget replyTo, MailTarget []to,MailTarget cc[],MailTarget bcc[],String subject,
			String body,Attachment []attachments,Date sendDate) {
		this.from = from;
		this.replyTo = replyTo;
		tos = to;
		ccs = cc;
		bccs = bcc;
		this.content = body;
		this.subject = subject;
		this.attachments = attachments;
		this.sendDate = sendDate;
		hasBeenRead = false;
	}

	public MailTarget getFrom(){
		return from;
	}

	public void setFrom(MailTarget from){
		this.from = from;
	}

	public MailTarget [] getBccs(){
		return bccs;
	}

	public void setBccs(MailTarget []bccs){
		this.bccs = bccs;
	}

	public MailTarget [] getTos(){
		return tos;
	}

	public void setTos(MailTarget []tos){
		this.tos = tos;
	}

	public MailTarget [] getCcs(){
		return ccs;
	}

	public void setCcs(MailTarget []ccs){
		this.ccs = ccs;
	}

	public Attachment[] getAttachments() {
		return attachments;
	}

	public void setAttachments(Attachment []attachments){
		this.attachments = attachments;
	}

	public boolean containsAttachements() {
		boolean contains = false;
		for(int i=0;contains==false && i<attachments.length;i++){
			contains = (attachments[i].isInline()==false);
		}
		return contains;
	}

	public String getSubject() {
		return subject;
	}

	public void setSubject(String subject){
		this.subject = subject;
	}

	public String getContent() {
		return content;
	}

	public void setContent(String content){
		this.content = content;
	}

	public boolean isSendAsText() {
		return sendAsText;
	}

	public String getContentAsText() {
		return contentAsText;
	}

	public void setContentAsText(String contentAsText) {
		this.contentAsText = contentAsText;
	}

	public void setSendAsText(boolean sendAsText) {
		this.sendAsText = sendAsText;
	}

	public MailTarget getReplyTo(){
		return replyTo;
	}


}
