/* 
 * Distributed as part of jtmail 1.0
 * 
 * Copyright (C) 2008 QArks.com
 *
 * Author: Pierre Meyer <support@qarks.com>
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2.1, as 
 * published by the Free Software Foundation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; see the file LICENSE.  If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */
package com.qarks.util.mail;

import java.io.*;

public class SmtpFileInputStream extends FileInputStream{

	private long totalRead;
	private long totalToRead;
	private ProgressListener listener;
	private String filePath;

	public SmtpFileInputStream(File file,ProgressListener listener) throws IOException{
		super(file);
		filePath = file.getAbsolutePath();
		totalRead = 0;
		totalToRead = file.length();
		this.listener = listener;
	}

	@Override
	public int read(byte b[], int off, int len) throws IOException {
		int read =  super.read(b,off,len);
			if (read>0){
			totalRead+=read;
			if (listener!=null){
				listener.onProgressUpdate(filePath,totalRead,totalToRead);
			}
		}
		return read;
	}

	@Override
	public int read(byte b[]) throws IOException {
		int read = super.read(b);
		if (read>0){
			totalRead+=read;
			if (listener!=null){
				listener.onProgressUpdate(filePath,totalRead,totalToRead);
			}
		}
		return read;
	}

	public long getProgress(){
		return totalRead;
	}
}