/* 
 * Distributed as part of jtmail 1.0
 * 
 * Copyright (C) 2008 QArks.com
 *
 * Author: Pierre Meyer <support@qarks.com>
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2.1, as 
 * published by the Free Software Foundation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
 * NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; see the file LICENSE.  If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */
package sample;

import com.qarks.util.mail.MailAttributeBinder;
import com.qarks.util.mail.ProgressListener;
import com.qarks.util.mail.SmtpHelper;

public class MailTemplateSample {

	public static void main(String args[]){
		MailTemplateSample sample = new MailTemplateSample();
		sample.sendMail();
	}
	
	public MailTemplateSample(){
	}
	
	private void sendMail(){
		String templatePath = "path to your mail template, including the file name";
		String charset = "ISO-8859-1";// can be any charset handled by the JVM
		ProgressListener progressListener = new SampleProgressListener();
		MailAttributeBinder binder = new SampleAttributeBinder();
		try {
			// mail can be sent as html or text, but of course, the template
			// content should also be html or text made according to this choice
			boolean isHtml = true;
			String from = "from@domain.com";
			String replyTo = "replyTo@domain.com";
			String to = "to@domain.com";;
			String smtpHost = "smtp.host";
			String smtpLogin = null;
			String smtpPassword = null;
			SmtpHelper.sendMail(binder,isHtml,"Subjet",
			        from,replyTo,to,
			        smtpHost,25,smtpLogin,smtpPassword,
			        templatePath,charset,progressListener);
		} 
		catch (Exception e) {
			e.printStackTrace();
		}		
	}
	
	////////////////////////////////////////////////////////////////////////////////
	
	public class SampleProgressListener implements ProgressListener{

		public void onProgressUpdate(String filePath, long nbRead, long totalToRead){
			System.out.println("on progress update for:"+filePath+":"+nbRead+"/"+totalToRead);
			// use this method to update progress bars, for insance
		}

		public void onInlinePictureAppended(String filePath, long fileSize) {
			// use this method to record all the inline pictures, to determine
			// the total amount of data to send so the total progress percent can
			// be computed
			System.out.println("on picture found:"+filePath+",size:"+fileSize);
		}		
	}
	
	////////////////////////////////////////////////////////////////////////////////
	
	public class SampleAttributeBinder implements MailAttributeBinder{
		
		public String getAttributeValue(String attributeName) {
			String resultat = "";				

			if ("PARAMETER1".equals(attributeName)){
				resultat = "VALUE1";
			}
			else if ("PARAMETER2".equals(attributeName)){
				resultat = "VALUE2";
			}				
			return resultat;
		}
	}
	
}
